@@ -1,4 +1,4 @@
-#pragma ident "@(#) $Id$"
+/* $Id: iread.c,v 1.36 2010/06/13 12:37:40 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: iread.c                                                       */
@@ -8,19 +8,19 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2009 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 3
  * of the License, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
@@ -46,9 +46,29 @@
 #include "bool.h"
 #include "mshell.h"
 #include "ratlptypes.h"
+#include "numb.h"
+#include "elem.h"
+#include "tuple.h"
 #include "mme.h"
+#include "set.h"
+#include "symbol.h"
+#include "define.h"
+#include "bound.h"
+#include "idxset.h"
+#include "mono.h"
+#include "term.h"
+#include "rdefpar.h"
+#include "conname.h"
+#include "stmt.h"
+#include "local.h"
+#include "list.h"
+#include "entry.h"
+#include "heap.h"
 #include "code.h"
 #include "inst.h"
+#include "xlpglue.h"
+#include "metaio.h"
+#include "strstore.h"
 
 /* read "datei" as "<1n,3s,12s,4n> %6s" skip 17 use 2000 fs " ;"
  */
@@ -771,7 +791,7 @@ CodeNode* i_read(CodeNode* self)
          {
             if (fields == MAX_FIELDS)
             {
-               fprintf(stderr, "*** Warning 213: More than %d input fields in line %d of %s\n",
+               fprintf(stderr, "--- Warning 213: More than %d input fields in line %d of %s\n",
                   fields, line, filename);
                code_errmsg(self);
             }
