@@ -1,4 +1,4 @@
-#pragma ident "@(#) $Id$"
+/* $Id: vinst.c,v 1.27 2010/06/13 12:37:41 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: vinst.c                                                       */
@@ -8,19 +8,19 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2009 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 3
  * of the License, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
@@ -31,13 +31,32 @@
 
 /* #define TRACE  1 */
 
+#include "lint.h"
 #include "bool.h"
 #include "mshell.h"
 #include "ratlptypes.h"
+#include "numb.h"
+#include "elem.h"
+#include "tuple.h"
 #include "mme.h"
+#include "set.h"
+#include "symbol.h"
+#include "define.h"
+#include "bound.h"
+#include "idxset.h"
+#include "mono.h"
+#include "term.h"
+#include "rdefpar.h"
+#include "conname.h"
+#include "stmt.h"
+#include "local.h"
+#include "list.h"
+#include "entry.h"
+#include "heap.h"
 #include "code.h"
 #include "inst.h"
 #include "xlpglue.h"
+#include "strstore.h"
 
 enum vbool_cmp_operator { VBOOL_LT, VBOOL_LE, VBOOL_EQ, VBOOL_NE, VBOOL_GE, VBOOL_GT };
 enum vbool_fixed_result { VBOOL_TRUE, VBOOL_FALSE, VBOOL_OPEN };
@@ -695,12 +714,12 @@ CodeNode* i_vbool_xor(CodeNode* self)
    /* a - b - re <= 0 */
    term = term_sub_term(term_a, term_b);
    term_add_elem(term, entry_result, numb_minusone());
-   create_new_constraint(cname, "_b", term, CON_LHS, numb_zero(), flags);
+   create_new_constraint(cname, "_b", term, CON_RHS, numb_zero(), flags);
    
    /* a - b + re >= 0 */
    term = term_sub_term(term_a, term_b);
    term_add_elem(term, entry_result, numb_one());
-   create_new_constraint(cname, "_c", term, CON_RHS, numb_zero(), flags);
+   create_new_constraint(cname, "_c", term, CON_LHS, numb_zero(), flags);
    
    /* a + b + re <= 2 */
    numb = numb_new_integer(2);
